!----------------------------------------------------------------------
!     Copyright (c) 2002 Shin-ichi Takehiro. All rights reserved.
!----------------------------------------------------------------------
!ɽ  wa_module
!
!  2002/02/02  ݹ  ¿
!      2002/02/07  ݹ  ؿ,ѿ̾ѹ
!      2002/03/25  ݹ  ⥸塼̾ѹ
!      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
!      2002/10/07  ݹ  , ̺ɸʬɲ
!      2005/04/23  ݹ  ڥȥϥ⥸塼ɲ
!
!         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
!
module wa_module

  use w_base_module
  use wa_base_module
  use w_deriv_module
  use w_integral_module
  use w_spectrum_module
  use wa_deriv_module
  use wa_integral_module
  use wa_spectrum_module

  private

  public wa_Initial                           ! 

  public x_Lon, y_Lat                         ! ʻҺɸ
  public x_Lon_Weight, y_Lat_Weight           ! ʻҺɸŤ
  public xy_Lon, xy_Lat                       ! ʻҺɸ(im,jm)
  public xy_w, w_xy, l_nm, nm_l               ! Ѵؿ
  public xya_wa, wa_xya                       ! Ѵؿ
  
  public w_Lapla_w, w_LaplaInv_w              ! ץ饷ȵձ黻
  public w_DLon_w                             ! ʬ
  public xy_GradLon_w, xy_GradLat_w           ! ۷ʬ
  public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
  public w_Div_xy_xy                          ! ȯʬ
  public w_Jacobian_w_w                       ! 䥳ӥ
  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)

  public wa_Lapla_wa, wa_LaplaInv_wa          ! ץ饷ȵձ黻
  public wa_DLon_wa                           ! ʬ
  public xya_GradLon_wa, xya_GradLat_wa       ! ۷ʬ
  public wa_DivLon_xya, wa_DivLat_xya         ! ȯʬ
  public wa_Div_xya_xya                       ! ȯʬ
  public wa_Jacobian_wa_wa                    ! 䥳ӥ
  public xya_GradLambda_wa, xya_GradMu_wa     ! ۷ʬ(,̺ɸ)
  public wa_DivLambda_xya, wa_DivMu_xya       ! ȯʬ(,̺ɸ)

  public IntLonLat_xy                         ! ٷʬ
  public y_IntLon_xy, IntLon_x                ! ʬ    
  public x_IntLat_xy, IntLat_y                ! ʬ    
  public AvrLonLat_xy                         ! ٷʿ
  public y_AvrLon_xy, AvrLon_x                ! ʿ    
  public x_AvrLat_xy, AvrLat_y                ! ʿ    

  public a_IntLonLat_xya                      ! ٷʬ
  public ya_IntLon_xya, a_IntLon_xa           ! ʬ    
  public xa_IntLat_xya, a_IntLat_ya           ! ʬ    
  public a_AvrLonLat_xya                      ! ٷʿ
  public ya_AvrLon_xya, a_AvrLon_xa           ! ʿ    
  public xa_AvrLat_xya, a_AvrLat_ya           ! ʿ    

  public nma_EnergyFromStreamfunc_wa          ! ͥ륮ڥȥ
                                              ! (ʿȿ n, Ӿȿ m )
  public na_EnergyFromStreamfunc_wa           ! ͥ륮ڥȥ
                                              ! (ʿȿ n )
  public nma_EnstrophyFromStreamfunc_wa       ! 󥹥ȥեڥȥ
                                              ! (ʿȿ n, Ӿȿ m )
  public na_EnstrophyFromStreamfunc_wa        ! 󥹥ȥեڥȥ
                                              !  (ʿȿ n )
  public wa_spectrum_VMiss                    ! »

  public nm_EnergyFromStreamfunc_w          ! ͥ륮ڥȥ           
                                            ! (ʿȿ n, Ӿȿ m )
  public n_EnergyFromStreamfunc_w           ! ͥ륮ڥȥ
                                            ! (ʿȿ n ) 
  public nm_EnstrophyFromStreamfunc_w       ! 󥹥ȥեڥȥ     
                                            ! (ʿȿ n, Ӿȿ m )
  public n_EnstrophyFromStreamfunc_w        ! 󥹥ȥեڥȥ  
                                            !  (ʿȿ n )
  public w_spectrum_VMiss                   ! »

contains
  subroutine wa_Initial(n_in,i_in,j_in,k_in)

    integer,intent(in) :: i_in, j_in          ! ʻ(, )
    integer,intent(in) :: n_in                ! ȿ
    integer,intent(in) :: k_in                ! ǡ(ؿ)򵭲

    call w_deriv_Initial(n_in,i_in,j_in)
    call wa_deriv_Initial(k_in)

  end subroutine wa_Initial

end module wa_module
